==> haskell-wai-app-static-3.1.4.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-app-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.4.1
id: wai-app-static-3.1.4.1-6e7f2369eaa1de2404aa1be869737966
key: waiap_HqWVpMQUvP0J2bXeIQhSpV
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
hs-libraries: HSwai-app-static-3.1.4.1-HqWVpMQUvP0J2bXeIQhSpV
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    cryptohash-conduit-0.1.1-dec777bba26b4960028433a6d8dd1c26
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-date-0.0.6.1-fcef85ec3f020c9d6f587d45aa9f4919
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
    wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
    wai-extra-3.0.13.1-754076fbe6d9ad0271640500660355fd
    warp-3.2.1-184b585d1fe25e67a905eacad9ccd211
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.4.1-17-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-app-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.4.1
id: wai-app-static-3.1.4.1-5d5bb24da470126a4cd2d84387cf1b92
key: waiap_IfgHB6BiYYI6Sh1YHgI9XN
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
hs-libraries: HSwai-app-static-3.1.4.1-IfgHB6BiYYI6Sh1YHgI9XN
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    cryptohash-conduit-0.1.1-9de27027fde4769c987c6d79fca939a3
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-date-0.0.6.1-fcef85ec3f020c9d6f587d45aa9f4919
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-extra-3.0.13.1-22d19709bfcccb29f4594bf354c81852
    warp-3.2.3-fdc49a5718602b1caa75db5ed6223617
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
